multiformats-config: Configuration for the 'multiformats' package.
==================================================================

.. image:: https://img.shields.io/badge/python-3.7+-green.svg
    :target: https://docs.python.org/3.7/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/v/multiformats-config.svg
    :target: https://pypi.python.org/pypi/multiformats-config/
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/status/multiformats-config.svg
    :target: https://pypi.python.org/pypi/multiformats-config/
    :alt: PyPI status

.. image:: http://www.mypy-lang.org/static/mypy_badge.svg
    :target: https://github.com/python/mypy
    :alt: Checked with Mypy

This module provides configuration and table information for the `multiformats <https://github.com/hashberg-io/multiformats/>`_ library.

License
-------

`MIT © Hashberg Ltd. <LICENSE>`_

See `additional Licenses <ADDITIONAL-LICENSES>`_ for licensing of the multicodec table, the multibase table and test vectors for multihashes.
